#!/bin/bash
# author           : P.R. Faasse (faasse@nlr.nl) <prf>
# maintainer       : P.R. Faasse
# source location  : see $srcurl below
# additional files : 
# 

#
# what package is going to be built
#
softname='QtCurve'
sbsname='qtcurve-kde3'
softversion='0.55.1'
archive="$softname-KDE3-$softversion.tar.bz2"

#
# The ZenWalk package version: indicated for/on what ZenWalk version
# the package has been created
#
# example: packageversion='1Z20' means: 
# 1  -> build 1 = first build, special: 0 = experimental/unsupported build
# Z  -> ZenWalk
# 20 -> ZenWalk version 2.0; 26 -> zenwalk 2.6 
#
packageversion='50.2'

#
# where could you get the source
#
srcurl="http://home.freeuk.com/cpdrummond/$archive"

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 make-jobs at once
#
#numjobs='-j6'
#
# I only have a 'light' computer: 2 make-jobs at once
#
numjobs='-j2'

#
#---------------------------------------------------------------------
# Note: for a rebuild you should normally not have to change anything
# below this comment
#---------------------------------------------------------------------
#

#
# a lonesome 'hook': the other end is at the bottom of the buildfile
# the combination gives me a full log of the build-process in the
# file: "$softname-$softversion-info.txt"
#
(

#
# we're going to do some cwd-hopping: this requires that we keep track
# of the starting-point
#
buildir=$(pwd)

#
# We'll use the SlackWare/ZenWalk database of installed packages: 
# The directory: /var/log/packages keeps a set of all installed 
# ZenWalk packages: one file per installed package
#

echo "-- build-time dependencies check -----"

depsok=passed

cd /var/log/packages
 
#
# dependencies check
#
for file in \
	kdelibs \
	qt-base \
; do
 
   #
   # Check the dependency
   #
   if [ -f $file-?.* ] ; then 
      echo "package: $file is installed: `ls -d $file*`: good ...";
   else
      echo "package: $file not found: please install a $file package first";
      depsok=fail
   fi
   #
done

cd $buildir
 
echo "Dependencies check result: $depsok"
#
# check if all dependencies are there
#
if [[ $depsok == passed ]]; then
   unset $depsok;
else
   exit 1;
fi

#
# check if the source files archive is present: we can do little without
# it
#
echo "-- source archive check -----"

if [ -r "$archive" ]; then 
  echo "Usable source archive: $archive found: good ...";
else 
  echo "No source archive: $archive found"
  echo "It is not possible to build the package without a source archive"
  echo "file; Please download the source archive from:"
  echo
  echo "$srcurl"
  echo
  exit 1;
fi

#
# start the real work
#
echo "-- start of the package building -----"

#
# the package 'destination'
#
prefix=/usr

#
# The architecture that the package is built for:
#
# arch='i486' -> the compiler uses only 80486 instructions
# tune='i686'  -> the optimising is done for a PII and above CPU
#
arch='i486'
tune='i686'

#
# parameters needed for the build process
#
package="$sbsname-$softversion-$arch-$packageversion"

#
# do package-specific settings 
#

#
# prepare the build result directory
#
dest="$buildir/$package"
#
rm -rf $dest
#
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
#
# prepare the directory for the build-file and assorted other 
# user-build related things
#
destsrc="$dest/usr/src/$sbsname-$softversion"
mkdir -p $destsrc

#
# put a slack-desc in place
#
cat <<EOF > $dest/install/slack-desc
        |-----handy-ruler------------------------------------------------------|
$sbsname: A theme to make Qt and GTK apps look alike
$sbsname: 
$sbsname: 
$sbsname: 
$sbsname: 
$sbsname: 
$sbsname:
$sbsname: 
$sbsname: 
$sbsname:
$sbsname: 
EOF

echo "-- Unpacking the source archive -----"

#
# extract the source archive
#
cd $buildir
file=$archive
srcdir="$(basename $file .tar.bz2)" 
rm -rf $srcdir
tar xf $file
cd $srcdir

#
# set target permissions
#
chown -R root.root . 
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

#
# configure package for compilation
#
echo "-- cmake -----"
(

 mkdir build
 cd build 

 #
 # the usual suspects of compiler options
 #
 export CFLAGS="-O2 -march=$arch -mtune=$tune"  
 export CXXFLAGS="-O2 -march=$arch -mtune=$tune"  
 #
 # we boldly enter the world of cmake...
 # we have to indicate the package to use by means of the path to qmake...
 #
 cmake \
   -DCMAKE_INSTALL_PREFIX=$prefix \
   ..

 #
 # make package
 #
 echo "-- make -----"
 make prefix=$prefix $numjobs 

 #
 # install package to the target directory
 #
 echo "-- make install -----"
 make prefix=$prefix install DESTDIR=$dest

)
#
# add 'default' files from the package source
#
echo "-- adding default files -----"

mkdir -p $dest/usr/doc/$sbsname
cp -a \
  AUTHORS COPYING INSTALL NEWS README TODO \
  $dest/usr/doc/$sbsname 

# 
# as per package rules: add the build-file itself
#
echo "-- adding package-rules files -----"

cp "$buildir/build-$sbsname.sh" \
   "$destsrc/build-$sbsname.sh"
chmod a+x "$destsrc/build-$sbsname.sh"
#
# generate an executable script that can be used to get the source
#
cat <<EOF > "$destsrc/getsrc-$sbsname.sh"
# 
# get the source(s) script
#
wget -c $srcurl
EOF

#
# it works easier if this file is actually executable :-)
#
chmod a+x "$destsrc/getsrc-$sbsname.sh"

#
# post-build processing: 
# - strip executables 
# - compress man-pages
#
echo "-- pre-package processing files -----"

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  for mandir in $(find . -name man -type d) ; do
    if [ -d $mandir ]; then
      ( cd $mandir
        find . -type f -name "*.?" -exec gzip -9 {} \;
      )
    fi
  done
)

#
# real packaging work: 
#
chown -R root.root $dest/$prefix

echo "--- packaging -----"

cd $dest
makepkg -p -l y -c n $dest.tgz
(
 cd $buildir
 #
 md5sum $package.tgz >$package.md5
 #
 EXCLUDE=kdelibs,qt-base \
 requiredbuilder -z $package.tgz >$package.dep
 #
)

#
# the other end of the lonesome hook: 
#
) 2>&1 | tee "$sbsname-$softversion-info.txt"

